c ----------------------------------------------------------------------
      subroutine nnamp0(tlab,ctrch,q,amp)
c ----------------------------------------------------------------------
c  Calculate the NN t-matrix for the incident energy tlab by sline, 
c  reaction channel ctrch, and the scattering angles, 
c  theta_{cm}(= 0(5) 180deg)   
c  Originally coded by Ulich Goetz, Latest update by M.I. 2013.8.27
c-----------------------------------------------------------------------
c Available NN t-matrix data by Bugg-Wilkin are for the kinetic energies
c   cttl:        1     2     3     4     5     6     7     8     9    10
c   tlab [mev]: 25    50   100   142   210   325   425   515   650   788
c----------------------------------------------------------------------- 
c INPUT from argument
c   tlab: Incident kinetic energy in the NN lab.frame
c   ctrch: reaction type specification
c     1       pp --> pp
c     2       np --> np
c     3       np --> pn (c.e.)
c     4      (pp --> pp + np --> np )/2 ! isospin indep. for absorption
c
c INPUT from file (unit 10):
c   ampbw(ithc,rch,sch):NN scattering amplitudes in Bugg's convention
c     ithc=0-18: scattering angle index (theta_{cm}=5*ithc deg) 
c     rch=1,2  : forward backward index
c     sch=1-5  : reaction type index
c 
c  OUTPUT to argument
c    q(0:36): table of the momentum transfers corresponding to 
c               the scattering angles theta_{cm}=0(5)180 deg
c    amp(ithc,1) =  a   =        alpha
c    amp(ithc,2) =  b   =        beta
c    amp(ithc,3) = -c/i =        gamma
c    amp(ithc,4) =  d   = g-h =  delta
c    amp(ithc,5) =  e   = g+h =  epsilon
c     ithc=0-36: momentum transfer index =  
c                scattering angle index (theta_{cm}=5*ithc deg) 
c ----------------------------------------------------------------------
      implicit none
c
      real*8 hc/197.326968d0/
      real*8 cpi/3.141592654d0/
      REAL*8 MN_AV/938.91937d0/         !Average nucleon mass
      real fpin,m
      parameter (fpin = 1.008)
      logical ctwri/.true./
      character 
     *  rchtxt(4)*8/' pp->pp ',' np->np ',' np->pn ','nn elast'/,
     *  tltxt*3
      integer itl,ithc,sch,tch,rch,ctrch,ntl/10/,ithc36
      real theta,norm,ar(0:18),ai(0:18),tl(10),tlab,tlhc
      real s,k,q(0:36)
      complex amp(0:36,5),amp0(0:36,0:1,5),amp1(0:36,4,5),
     1           amp2(0:36,4,5,10),amp3(0:36,4,5),ampbw(0:18,2,5)
      complex amptla(10),amptlb(10),amptlc(10),amptld(10),spcp
c
      m=MN_AV/hc
c
      open(unit=10,status='old')
c
      tlhc=tlab/hc
      s= 4*m**2 + 2*m*tlhc
      k= sqrt(m*tlhc/2)
      do 210 ithc=0,36
        theta = ithc*5*cpi/180
        q(ithc) = 2*k*sin(theta/2)
  210 continue
      if (.not.ctwri) write(8,'(x,1p,''s='',e10.3,''k='',e10.3)') s,k
      norm = 4*cpi/sqrt(s)
      do 120 itl=1,ntl
        read(10,*,end=9000) tl(itl)
        tl(itl) = tl(itl)*1000/hc
        do 100 rch=1,2
          do 90 sch=1,5
            read(10,*) (ar(ithc),ithc=0,18)
            read(10,*) (ai(ithc),ithc=0,18)
            do 80 ithc=0,18
              ampbw(ithc,rch,sch) = cmplx(ar(ithc),ai(ithc))
   80       continue
   90     continue
  100   continue
        do 94 ithc=0,18
          do 93 sch=1,5
            amp0(ithc,0,sch)=2.0*ampbw(ithc,2,sch)-ampbw(ithc,1,sch)
            amp0(ithc,1,sch)=ampbw(ithc,1,sch)
   93     continue
   94   continue
        do 99 tch=0,1
          do 98 ithc=19,36
            ithc36=36-ithc
            amp0(ithc,tch,1)=(-1)**tch*0.5*(amp0(ithc36,tch,1)
     1                  +amp0(ithc36,tch,3)+2.0*amp0(ithc36,tch,4))
            amp0(ithc,tch,3)=(-1)**tch*0.5*(amp0(ithc36,tch,1)
     1                  +amp0(ithc36,tch,3)-2.0*amp0(ithc36,tch,4))
            amp0(ithc,tch,4)=(-1)**tch*0.5*(amp0(ithc36,tch,1)
     1                  -amp0(ithc36,tch,3))
            amp0(ithc,tch,2)=(-1)**(tch+1)*amp0(ithc36,tch,2)
            amp0(ithc,tch,5)=(-1)**(tch+1)*amp0(ithc36,tch,5)
   98     continue
   99   continue
        if(itl.eq.8) then
        end if
        do 97 sch=1,5
          do 96 ithc=0,36
            amp1(ithc,1,sch)=amp0(ithc,1,sch)
            amp1(ithc,2,sch)=0.5*(amp0(ithc,1,sch)+amp0(ithc,0,sch))
            amp1(ithc,3,sch)=0.5*(amp0(ithc,1,sch)-amp0(ithc,0,sch))
            amp1(ithc,4,sch)=0.75*amp0(ithc,1,sch)+0.25*amp0(ithc,0,sch)
   96     continue
   97   continue
c         amp2(...,i) i = 1:alpha, 2:beta, 3:gamma, 4:delta, 5:epsilon
        do 105 rch=1,4
          do 95 ithc=0,36
            amp2(ithc,rch,1,itl)= norm*amp1(ithc,rch,1)
            amp2(ithc,rch,2,itl)= norm*amp1(ithc,rch,3)
            amp2(ithc,rch,3,itl)=-norm*amp1(ithc,rch,2)
            amp2(ithc,rch,4,itl)= norm*(amp1(ithc,rch,4)
     1                                 -amp1(ithc,rch,5))
            amp2(ithc,rch,5,itl)= norm*(amp1(ithc,rch,4)
     1                                 +amp1(ithc,rch,5))
   95     continue
  105   continue
  120 continue
      close(10)
c     end reading of amplitudes
c
      ntl=itl-1
      write(tltxt,'(i3)') nint(tlab)
      do 180 rch=1,4
        do 170 sch=1,5
          do 160 ithc=0,36
            do 150 itl=1,ntl
              amptla(itl)=amp2(ithc,rch,sch,itl)
  150       continue
            call sp0cp(ntl,tl,amptla,amptlb,amptlc,amptld)
            amp3(ithc,rch,sch)=spcp(ntl,tlhc,tl,amptla,amptlb,
     1                                          amptlc,amptld)
  160     continue
  170   continue
  180 continue
c
      if (ctwri) goto 230
c       write pp, pn, c.e., and nn amplitudes
        do 220 rch=1,4
          write(8,'(5('' ('',f6.3,'','',f6.3,'')''))')
     1      ((amp3(ithc,rch,sch),sch=1,5),ithc=0,36)
  220   continue
  230 continue
c
      do 260 sch=1,5
c       transfer chosen amp into return variables
        do 250 ithc=0,36
          amp(ithc,sch) = amp3(ithc,ctrch,sch)
  250   continue
  260 continue
c
      return
 9000 stop
      end
