c--------------------------------------------------------------------
C
      subroutine sobcal(nan,itrj,ampm,NDMT,knmin,knmax,sintq)
C
c--------------------------------------------------------------------
c      Calculation of cross section & spin observables
c      for the fixed theta, omega, Jtr, parity and N-Delta components,
c      and their sums over N-Delta components..
c-------------------------------------------------------------------
c  INPUT THROUGH THE ARGUMENTS
c    nan  : angle number
c    itrj : Transfer J + 1                                      
c    NDMT : maximum of Nucleon-Delta index NDM
c      NDM; Response function specification 
C           for N/Delta-hole components or sum of them (full)
c           =1;(N<->N), =2;(N<->D), =3;(D<->D), =NDMT(=1 or 4);full            
c    knmin : minimum of transferred parity specification
c    knmax : maximum of transferred parity specification
c    sintq : sin(thq')=sin(pi-thq)=sin(pi/2-thp)=cos(thp)
C                       [ thq',thp < pi/2)] defined in basic3,f            
c    ampm(msf,msi,msf',msi',kn,NDM) : 
C      Response functions R_{S} for the (outer impact) source function S. 
c       msi, msi': z-components of the nucleon spin in the incident channel 
c       msf, msf': z-components of the nucleon spin in the exit channel 
c       kn; =1: natural prity, =2: unnatural parity
c       NDM; N/Delta-hole specification(see above) 
C
C  INPUT FROM COMMON BASE                   
c    fk1(2)  : The incident and exit momenta in the c.m. system 
c    pspn1(2): The spin of the projectile and the ejectile
c    fmud1(2): The reduced energies of the incident and exit channel
c
C--------------------------------------------------------------------
C  OUTPUT TO COMMON THETA
C
C   All are in unit of [mb/sr MeV]
C   For ID_{ij}, i and j refer the incident and exit channel respectively
C   Relativistic spin rotation is neglected
c  
c    Xsct(itrj,kn,NDM): I(J,pi,ND)     for given theta and omega
c    IPy (itrj,kn,NDM): IPy(J,pi,ND)   for given theta and omega
c    IAy (itrj,kn,NDM): IAy(J,pi,ND)   for given theta and omega
c
c    IDxx(itrj,kn,NDM): IDxx(J,pi,ND)  for given theta and omega
c    IDxz(itrj,kn,NDM): IDxz(J,pi,ND)  for given theta and omega
c    IDyy(itrj,kn,NDM): IDyy(J,pi,ND)  for given theta and omega
c    IDzx(itrj,kn,NDM): IDzx(J,pi,ND)  for given theta and omega
c    IDzz(itrj,kn,NDM): IDzz(J,pi,ND)  for given theta and omega
c
c    IDSS(jtr,kn,NDM) : IDSS'(J,pi,ND) for given theta and omega
c    IDSL(itrj,kn,NDM): IDSL'(J,pi,ND) for given theta and omega
c    IDNN(itrj,kn,NDM): IDNN'(J,pi,ND) for given theta and omega
c    IDLS(itrj,kn,NDM): IDLS'(J,pi,ND) for given theta and omega
c    IDLL(itrj,kn,NDM): IDLL'(J,pi,ND) for given theta and omega
c
c    IDqq(itrj,kn,NDM): IDqq(J,pi,ND)  for given theta and omega
c    IDqp(itrj,kn,NDM): IDqp(J,pi,ND)  for given theta and omega
c    IDpq(itrj,kn,NDM): IDpq(J,pi,ND)  for given theta and omega
c    IDpp(itrj,kn,NDM): IDpp(J,pi,ND)  for given theta and omega
c
c--------------------------------------------------------------------
      include 'dimn.fh'
      include 'base.fh'
      include 'theta.fh'
      complex ampm(2,2,2,2,2,4)
c
      real*8 hc/197.326968d0/
      real*8 cpi/3.141592654d0/
c
      th_l = thetld(nan)*cpi/180.0
      jtr=itrj-1
      mxsi=pspn1(1)*2.0+1.01
      mxsf=pspn1(2)*2.0+1.01
C
      geom=10./(2.*cpi*hc*hc)**2*(fk1(2)/fk1(1))
     &    /(2.*pspn1(1)+1.)/(fk1(1)*fk1(2))**2
     &    *fmud1(1)*fmud1(2)
c
      snl=sin(th_l)
      csl=cos(th_l)
      sintq2=sintq*sintq
      costq2=1.0-sintq2
      stqctq=sintq*sqrt(costq2)
c--------------------------------------------------------------------
c    SET ZERO
c---------------------------------------------------------------------
      do NDM=1,4
        do kn=1,2
           Xsct(itrj,kn,NDM)= 0.0
           IPy(itrj,kn,NDM) = 0.0
           IAy(itrj,kn,NDM) = 0.0
           IDxx(itrj,kn,NDM)= 0.0
           IDxz(itrj,kn,NDM)= 0.0
           IDyy(itrj,kn,NDM)= 0.0
           IDzx(itrj,kn,NDM)= 0.0
           IDzz(itrj,kn,NDM)= 0.0
           IDSS(itrj,kn,NDM)= 0.0
           IDSL(itrj,kn,NDM)= 0.0
           IDNN(itrj,kn,NDM)= 0.0
           IDLS(itrj,kn,NDM)= 0.0
           IDLL(itrj,kn,NDM)= 0.0
           IDqq(itrj,kn,NDM)= 0.0
           IDqp(itrj,kn,NDM)= 0.0
           IDpq(itrj,kn,NDM)= 0.0
           IDpp(itrj,kn,NDM)= 0.0
        end do
      end do
c--------------------------------------------------------------------
      do NDM=1,NDMT
        do kn=knmin,knmax
C
          if((mxsi.eq.2).and.(mxsf.eq.2)) then
        Xsct(itrj,kn,NDM)=geom*real(ampm(2,2,2,2,kn,NDM)
     &                             +ampm(2,1,2,1,kn,NDM)
     &                             +ampm(1,2,1,2,kn,NDM)
     &                             +ampm(1,1,1,1,kn,NDM))
        IPy(itrj,kn,NDM)=2.0*geom*aimag(ampm(2,2,1,2,kn,NDM)
     &                                 +ampm(2,1,1,1,kn,NDM))
        IAy(itrj,kn,NDM)=2.0*geom*aimag(ampm(2,1,2,2,kn,NDM)
     &                                 +ampm(1,1,1,2,kn,NDM))
        IDxx(itrj,kn,NDM)=2.0*geom*real(ampm(1,1,2,2,kn,NDM)
     &                                 +ampm(1,2,2,1,kn,NDM))
        IDxz(itrj,kn,NDM)=2.0*geom*real(ampm(2,2,2,1,kn,NDM)
     &                                 -ampm(1,2,1,1,kn,NDM))
        IDyy(itrj,kn,NDM)=2.0*geom*real(ampm(1,1,2,2,kn,NDM)
     &                                 -ampm(1,2,2,1,kn,NDM))
        IDzx(itrj,kn,NDM)=2.0*geom*real(ampm(1,2,2,2,kn,NDM)
     &                                 -ampm(2,1,1,1,kn,NDM))
        IDzz(itrj,kn,NDM)=geom*real(ampm(2,2,2,2,kn,NDM)
     &                             -ampm(2,1,2,1,kn,NDM)
     &                             -ampm(1,2,1,2,kn,NDM)
     &                             +ampm(1,1,1,1,kn,NDM))
C
          IDSS(itrj,kn,NDM)= IDxx(itrj,kn,NDM)*csl
     &                      -IDxz(itrj,kn,NDM)*snl
          IDSL(itrj,kn,NDM)= IDxx(itrj,kn,NDM)*snl
     &                      +IDxz(itrj,kn,NDM)*csl
          IDNN(itrj,kn,NDM)= IDyy(itrj,kn,NDM)
          IDLS(itrj,kn,NDM)= IDzx(itrj,kn,NDM)*csl
     &                      -IDzz(itrj,kn,NDM)*snl
          IDLL(itrj,kn,NDM)= IDzx(itrj,kn,NDM)*snl
     &                      +IDzz(itrj,kn,NDM)*csl
          IDqq(itrj,kn,NDM)
     &    = IDxx(itrj,kn,NDM)*sintq2+IDzz(itrj,kn,NDM)*costq2
     &    -(IDxz(itrj,kn,NDM)+IDzx(itrj,kn,NDM))*stqctq
          IDqp(itrj,kn,NDM)
     &    = IDxz(itrj,kn,NDM)*sintq2-IDzx(itrj,kn,NDM)*costq2
     &    +(IDxx(itrj,kn,NDM)-IDzz(itrj,kn,NDM))*stqctq
          IDpq(itrj,kn,NDM)
     &    =-IDxz(itrj,kn,NDM)*costq2+IDzx(itrj,kn,NDM)*sintq2
     &    +(IDxx(itrj,kn,NDM)-IDzz(itrj,kn,NDM))*stqctq
          IDpp(itrj,kn,NDM)
     &    = IDxx(itrj,kn,NDM)*costq2+IDzz(itrj,kn,NDM)*sintq2
     &    +(IDxz(itrj,kn,NDM)+IDzx(itrj,kn,NDM))*stqctq
          end if
        end do
      end do
c
      return
      end
