c----------------------------------------------------------------------
      subroutine wxsecJ(nan,omeg_l,itrj,NDMT,knmin,knmax,pspn1)
c----------------------------------------------------------------------
c      Output cross section & spin observables
c      for the fixed theta, Jtr and N-Delta comp if KTOUT_XSJ=1
c-------------------------------------------------------------------
c  INPUT THROUGH THE ARGUMENTS
c    nan  : angle number
c    omeg_l:Energy transfer in lab (MeV)                                       
c    itrj : Transfer J + 1                          
c    NDMT : maximum of Nucleon-Delta index NDM
c      NDM; Response function specification 
C           for N/Delta-hole components or sum of them (full)
c           =1;(N<->N), =2;(N<->D), =3;(D<->D), =NDMT(=1 or 4);full            
c    knmin : minimum of transferred parity specification
c    knmax : maximum of transferred parity specification
c    pspn1(2): The spin of the projectile and the ejectile
c  
c    Xsct(itrj,kn,NDM): I(J,pi,ND)     for given theta and omega
c    IPy (itrj,kn,NDM): IPy(J,pi,ND)   for given theta and omega
c    IAy (itrj,kn,NDM): IAy(J,pi,ND)   for given theta and omega
c
c    IDxx(itrj,kn,NDM): IDxx(J,pi,ND)  for given theta and omega
c    IDxz(itrj,kn,NDM): IDxz(J,pi,ND)  for given theta and omega
c    IDyy(itrj,kn,NDM): IDyy(J,pi,ND)  for given theta and omega
c    IDzx(itrj,kn,NDM): IDzx(J,pi,ND)  for given theta and omega
c    IDzz(itrj,kn,NDM): IDzz(J,pi,ND)  for given theta and omega
c
c    IDSS(jtr,kn,NDM) : IDSS'(J,pi,ND) for given theta and omega
c    IDSL(itrj,kn,NDM): IDSL'(J,pi,ND) for given theta and omega
c    IDNN(itrj,kn,NDM): IDNN'(J,pi,ND) for given theta and omega
c    IDLS(itrj,kn,NDM): IDLS'(J,pi,ND) for given theta and omega
c    IDLL(itrj,kn,NDM): IDLL'(J,pi,ND) for given theta and omega
c
c    IDqq(itrj,kn,NDM): IDqq(J,pi,ND)  for given theta and omega
c    IDqp(itrj,kn,NDM): IDqp(J,pi,ND)  for given theta and omega
c    IDpq(itrj,kn,NDM): IDpq(J,pi,ND)  for given theta and omega
c    IDpp(itrj,kn,NDM): IDpp(J,pi,ND)  for given theta and omega
c--------------------------------------------------------------------
      include 'dimn.fh'
      include 'theta.fh'
      real*4 pspn1(2)
      character msg*10
c
      mxsi=pspn1(1)*2.0+1.01
      mxsf=pspn1(2)*2.0+1.01
      jtr=itrj-1
c
      write(6,3000) omeg_l,thetld(nan)
 3000 format(/'*** Cross Sections and Spin Observables for Each Jtr',
     & //' omega(l) =',f6.2,'  theta(l) =',f6.2)
c
      do  NDM=1,NDMT
       do  kn=knmin,knmax
c
        if((mxsi.eq.2).and.(mxsf.eq.2)) then
          if(kn.eq.1) then
            msg='natural '
          else
            msg='unnatural   '
          end if
          write(6,3100) jtr,msg, NDM
 3100  format(/' Jtr=',i2,3x,a10,2x,'NDM = ',I1)
          write(6,3201)
 3201  format('    X-sec(c)',7x,'Polar.',4x,'Analyz.')
          write(6,3202) Xsct(itrj,kn,NDM),
     &                  100.0*IPy(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &                  100.0*IAy(itrj,kn,NDM)/Xsct(itrj,kn,NDMT)
 3202  format(2x,e12.5,2f10.3)
C=======================================================================
          write(6,3211)
 3211  format('      Dxx       Dxz       Dyy       Dzx       Dzz')
          write(6,3220) 
     &      100.0*IDxx(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDxz(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDyy(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDzx(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDzz(itrj,kn,NDM)/Xsct(itrj,kn,NDMT)
C=======================================================================
          write(6,3213)
          write(6,3220) 
     &      100.0*IDSS(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDSL(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDNN(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDLS(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDLL(itrj,kn,NDM)/Xsct(itrj,kn,NDMT)
 3213  format('      Dss       Dsl       Dnn       Dsl       Dll')
C=======================================================================
          write(6,3214)
          write(6,3220) 
     &      100.0*IDqq(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDqp(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDnn(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDpq(itrj,kn,NDM)/Xsct(itrj,kn,NDMT),
     &      100.0*IDpp(itrj,kn,NDM)/Xsct(itrj,kn,NDMT)
 3214  format('      Dqq       Dqp       Dnn       Dpq       Dpp')
C=======================================================================
 3220  format(5f10.3)
        else
           write(*,*)
          write(6,3300) thetld(nan),Xsct(itrj,kn,NDM)
        end if
       end do
      end do
 3300  format(' theta(l)=',f7.2,4x,'x=',e12.6)
c
      return
      end
