c----------------------------------------------------------
      subroutine xpol(nan,nw,NDMT,knmin,knmax,
     &     itrjmn,itrjmx1,fcm2l,ampq2,ampp2)
C-------------------------------------------------------------------
c     Calculate the cross sections, P, A and Dij 
c     by summing up over the transfer J and the parity
c-------------------------------------------------------------------
c  INPUT THROUGH THE ARGUMENTS
c    nan: angle number
c    nw : omega number
c    itrjmn : minimum of transferred J
c    itrjmx1: maximum of transferred J                 
c    knmin : minimum of transferred parity specification
c    knmax : maximum of transferred parity specification                 
c    NDMT  : maximum of Nucleon-Delta index NDM
c       NDM; Response function specification 
C            for N/Delta-hole components or sum of them (full)
c            =1;(N<->N), =2;(N<->D), =3;(D<->D), = NDMT(=1 or 4);full
C                 
c    fcm2l : transformation factor from cm to lab                  
c    ampq2 : |E(q,E_lab)|^2; square of NN-amplitude E                 
c    ampp2 : |F(q,E_lab)|^2; square of NN-amplitude F
C
C  INPUT FROM COMMON THETA                   
c    Xsct(jtr,kn,NDM): I(J,pi,ND)     for given theta and omega
c    IPy(jtr,kn,NDM) : IPy(J,pi,ND)   for given theta and omega
c    IAy(jtr,kn,NDM) : IAy(J,pi,ND)   for given theta and omega
c    IDSS(jtr,kn,NDM): IDSS'(J,pi,ND) for given theta and omega
c    IDSL(jtr,kn,NDM): IDSL'(J,pi,ND) for given theta and omega
c    IDNN(jtr,kn,NDM): IDNN'(J,pi,ND) for given theta and omega
c    IDLS(jtr,kn,NDM): IDLS'(J,pi,ND) for given theta and omega
c    IDLL(jtr,kn,NDM): IDLL'(J,pi,ND) for given theta and omega
c    IDqq(jtr,kn,NDM): IDqq(J,pi,ND)  for given theta and omega
c    IDqp(jtr,kn,NDM): IDqp(J,pi,ND)  for given theta and omega
c    IDpq(jtr,kn,NDM): IDpq(J,pi,ND)  for given theta and omega
c    IDpp(jtr,kn,NDM): IDpp(J,pi,ND)  for given theta and omega
C
C-------------------------------------------------------------------
C  OUTPUT TO COMMON XSEC
C
C   Cross sections in unit of [mb/sr MeV]
C     sumx(nan,nw,NDM) :I(theta,omega,NDM); cross sec. in cm frame
C     sumxl(nan,nw,NDM):I_lab(theta,omega,NDM); cross sec. in lab frame
C
C   Polarization & Analysing power in unit of [%]
C     pols(nan,nw,NDM) :Py(theta,omega,NDM)
C     asyms(nan,nw,NDM):Ay(theta,omega,NDM)
C
C   Polarization transfer coefficients D_{ij} in unit of [%]
C   i and j refer the incident and exit channel respectively   
C     DSS(nan,nw,NDM)  :DSS'(theta,omega,NDM)
C     DSL(nan,nw,NDM)  :DSL'(theta,omega,NDM)
C     DNN(nan,nw,NDM)  :DNN'(theta,omega,NDM)
C     DLS(nan,nw,NDM)  :DLS'(theta,omega,NDM)
C     DLL(nan,nw,NDM)  :DLL'(theta,omega,NDM)
C     Dqq(nan,nw,NDM)  :Dqq(theta,omega,NDM)
C     Dqp(nan,nw,NDM)  :Dqp(theta,omega,NDM)
C     Dpq(nan,nw,NDM)  :Dpq(theta,omega,NDM)
C     Dpp(nan,nw,NDM)  :Dpp(theta,omega,NDM)
C
C  Spin polarized cross sections in the lab. system in unit of [mb/sr MeV]
C     xid0l(nan,nw,NDM):ID0(theta,omega,NDM)
C     xidnl(nan,nw,NDM):IDn(theta,omega,NDM)
C     xidql(nan,nw,NDM):IDq(theta,omega,NDM)
C     xidpl(nan,nw,NDM):IDp(theta,omega,NDM)
C
C  L/T ratio  
C     ratlt(nan,nw,NDM): Longitudinal-transverse response ratios
C
c--------------------------------------------------------------------
      include 'dimn.fh'
      include 'theta.fh'
      include 'xsec.fh'
c
      dimension sump(4),suma(4)
      dimension sumSS(4),sumSL(4),sumNN(4),sumLS(4),sumLL(4)
      dimension sumqq(4),sumqp(4),sumpq(4),sumpp(4)
c
c****sum of cross sections, etc. over jtr
c
      ijmn1=itrjmn+1
      ijmx1=itrjmx1+1
c
      DO NDM=1,NDMT
        sumx(nan,nw,NDM) =0.0
        do itrj=ijmn1,ijmx1
          do  kn = knmin,knmax
            sumx(nan,nw,NDM) =sumx(nan,nw,NDM) +Xsct(itrj,kn,NDM)
          end do   
        end do
        sumxl(nan,nw,NDM)=sumx(nan,nw,NDM)*fcm2l
      end do
c
      DO NDM=1,NDMT
        sump(NDM) =0.0
        suma(NDM) =0.0
        sumSS(NDM)=0.0
        sumSL(NDM)=0.0
        sumNN(NDM)=0.0
        sumLS(NDM)=0.0
        sumLL(NDM)=0.0
        sumqq(NDM)=0.0
        sumqp(NDM)=0.0
        sumpq(NDM)=0.0
        sumpp(NDM)=0.0
        do itrj=ijmn1,ijmx1
          do  kn = knmin,knmax
            sump(NDM) =sump(NDM) +IPy(itrj,kn,NDM)
            suma(NDM) =suma(NDM) +IAy(itrj,kn,NDM)
            sumSS(NDM)=sumSS(NDM)+IDSS(itrj,kn,NDM)
            sumSL(NDM)=sumSL(NDM)+IDSL(itrj,kn,NDM)
            sumNN(NDM)=sumNN(NDM)+IDNN(itrj,kn,NDM)
            sumLS(NDM)=sumLS(NDM)+IDLS(itrj,kn,NDM)
            sumLL(NDM)=sumLL(NDM)+IDLL(itrj,kn,NDM)
            sumqq(NDM)=sumqq(NDM)+IDqq(itrj,kn,NDM)
            sumqp(NDM)=sumqp(NDM)+IDqp(itrj,kn,NDM)
            sumpq(NDM)=sumpq(NDM)+IDpq(itrj,kn,NDM)
            sumpp(NDM)=sumpp(NDM)+IDpp(itrj,kn,NDM)
          end do   
        end do
C
        pols(nan,nw,NDM) =100.0*sump(NDM)/sumx(nan,nw,NDMT)
        asyms(nan,nw,NDM)=100.0*suma(NDM)/sumx(nan,nw,NDMT)
        DSS(nan,nw,NDM)  =100.0*sumSS(NDM)/sumx(nan,nw,NDMT)
        DSL(nan,nw,NDM)  =100.0*sumSL(NDM)/sumx(nan,nw,NDMT)
        DNN(nan,nw,NDM)  =100.0*sumNN(NDM)/sumx(nan,nw,NDMT)
        DLS(nan,nw,NDM)  =100.0*sumLS(NDM)/sumx(nan,nw,NDMT)
        DLL(nan,nw,NDM)  =100.0*sumLL(NDM)/sumx(nan,nw,NDMT)
        Dqq(nan,nw,NDM)  =100.0*sumqq(NDM)/sumx(nan,nw,NDMT)
        Dqp(nan,nw,NDM)  =100.0*sumqp(NDM)/sumx(nan,nw,NDMT)
        Dpq(nan,nw,NDM)  =100.0*sumpq(NDM)/sumx(nan,nw,NDMT)
        Dpp(nan,nw,NDM)  =100.0*sumpp(NDM)/sumx(nan,nw,NDMT)
C
        xid0l(nan,nw,NDM)=0.25*fcm2l*
     &       (sumx(nan,nw,NDM)+sumnn(NDM)+sumqq(NDM)+sumpp(NDM))
        xidnl(nan,nw,NDM)=0.25*fcm2l*
     &       (sumx(nan,nw,NDM)+sumnn(NDM)-sumqq(NDM)-sumpp(NDM))
        xidql(nan,nw,NDM)=0.25*fcm2l*
     &       (sumx(nan,nw,NDM)-sumnn(NDM)+sumqq(NDM)-sumpp(NDM))
        xidpl(nan,nw,NDM)=0.25*fcm2l*
     &       (sumx(nan,nw,NDM)-sumnn(NDM)-sumqq(NDM)+sumpp(NDM))
C
        ratlt(nan,nw,NDM)=
     &       xidql(nan,nw,NDM)/ xidpl(nan,nw,NDM)*ampp2/ampq2
      end do
C
      return
      end
